@@ -7,6 +7,7 @@ All rights reserved.
 """
 
 import requests
+import json
 
 
 class RCAPIError(Exception):
@@ -41,7 +42,8 @@ class RCRequest(object):
         self.type = qtype
         if qtype:
             self.validate_pl()
-        self.fmt = payload['format']
+        fmt_key = 'returnFormat' if 'returnFormat' in payload else 'format'
+        self.fmt = payload[fmt_key]
 
     def validate_pl(self):
         """Check that at least required params exist
@@ -65,7 +67,7 @@ class RCRequest(object):
             req_content = 'file'
             err_msg = 'Exporting file but content is not file'
         if self.type == 'imp_file':
-            extra = ['action', 'record', 'field', 'file']
+            extra = ['action', 'record', 'field']
             req_content = 'file'
             err_msg = 'Importing file but content is not file'
         if self.type == 'exp_event':
@@ -100,17 +102,35 @@ class RCRequest(object):
         except KeyError:
             raise RCAPIError('content not in payload')
 
-    def execute(self):
+    def execute(self, **kwargs):
         """Execute the API request and return data
 
+        Parameters
+        ----------
+        kwargs: passed to requests.post()
+
         Returns
         -------
         Return data object from JSON decoding process if format=='json',
         else return raw string (ie format=='csv'|'xml')
         """
         header = {'Content-Type': 'application/x-www-form-urlencoded'}
-        r = requests.post(self.url, data=self.payload, headers=header)
-        if self.fmt == 'json':
-            return r.json
+        r = requests.post(self.url, data=self.payload, headers=header,
+            **kwargs)
+        if self.type != 'exp_file':
+            if self.fmt == 'json':
+                try:
+                    # Need to sanitize newlines, otherwise json decoding can fail
+                    content = json.loads(r.text.replace('\n', '|'))
+                except ValueError as e:
+                    if self.type == 'imp_file':
+                        # no response for successful file imports
+                        content = {}
+                    else:
+                        raise ValueError(e)
+            else:
+                content = r.text
         else:
-            return r.text
+            # File exports need to return non-unicoded content
+            content = r.content
+        return content, r.headers
